| Title: | Haahka bird migration browser |
|---|---|
| Description: | Bird Migration browser. |
| Authors: | William Morris & Joona Lehtomaki |
| Maintainer: | William K. Morris <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.7.31.9000 |
| Built: | 2026-05-20 10:31:20 UTC |
| Source: | https://github.com/luomus/haahka |
Return full language names instead of a language code.
get_languages(x)get_languages(x)
x |
Language shortcode. |
Get month names in a given language.
get_months(lang = "en", format)get_months(lang = "en", format)
lang |
Language shortcode. |
format |
Format. |
Get species common names in a locale.
get_species_names(lang, sp_data)get_species_names(lang, sp_data)
lang |
Language shortcode. |
sp_data |
Species names. |
Get record value for a species.
get_value(season, type, value, records, and = "and")get_value(season, type, value, records, and = "and")
season |
Character. "Spring" or "Autumn". |
type |
Character. Migration "Migr" or "Local". |
value |
Character. "date_string" or "Sum". |
records |
Records table. |
and |
Character. "and" string. |
Create a date label.
make_date_label(x, lang)make_date_label(x, lang)
x |
Date. |
lang |
Language shortcode. |
Parse description text.
parse_description(text, lang)parse_description(text, lang)
text |
Description text. |
lang |
Language shortcode. |
An average is calculated over a specified window and assigned to the day in the middle of the window.
tile_observations(x, value)tile_observations(x, value)
x |
A data.frame. |
value |
String name of the variable containing numeric observation values. |
A data.frame with dates and corresponding (rounded) averages.